Index: trunk/Nebulous/nebclient/src/soapStub.h
===================================================================
--- trunk/Nebulous/nebclient/src/soapStub.h	(revision 19542)
+++ trunk/Nebulous/nebclient/src/soapStub.h	(revision 20110)
@@ -61,26 +61,26 @@
 
 #ifndef SOAP_TYPE_ns1__rename_USCOREobjectResponse
-#define SOAP_TYPE_ns1__rename_USCOREobjectResponse (13)
+#define SOAP_TYPE_ns1__rename_USCOREobjectResponse (14)
 /* ns1:rename_objectResponse */
 struct ns1__rename_USCOREobjectResponse
 {
-	char **result;	/* SOAP 1.2 RPC return element (when namespace qualified) */	/* optional element of type xsd:string */
+	int *result;	/* SOAP 1.2 RPC return element (when namespace qualified) */	/* optional element of type xsd:int */
 };
 #endif
 
 #ifndef SOAP_TYPE_ns1__rename_USCOREobject
-#define SOAP_TYPE_ns1__rename_USCOREobject (14)
+#define SOAP_TYPE_ns1__rename_USCOREobject (15)
 /* ns1:rename_object */
 struct ns1__rename_USCOREobject
 {
-	char *key;	/* optional element of type xsd:string */
-	char *newkey;	/* optional element of type xsd:string */
-};
-#endif
-
-#ifndef SOAP_TYPE_ns1__rename_USCOREobject_Response
-#define SOAP_TYPE_ns1__rename_USCOREobject_Response (16)
-/* ns1:rename_object-Response */
-struct ns1__rename_USCOREobject_Response
+	char *key1;	/* optional element of type xsd:string */
+	char *key2;	/* optional element of type xsd:string */
+};
+#endif
+
+#ifndef SOAP_TYPE_ns1__swap_USCOREobjectsResponse
+#define SOAP_TYPE_ns1__swap_USCOREobjectsResponse (17)
+/* ns1:swap_objectsResponse */
+struct ns1__swap_USCOREobjectsResponse
 {
 	char **result;	/* SOAP 1.2 RPC return element (when namespace qualified) */	/* optional element of type xsd:string */
@@ -88,16 +88,16 @@
 #endif
 
-#ifndef SOAP_TYPE_ns1__rename_USCOREobject_
-#define SOAP_TYPE_ns1__rename_USCOREobject_ (17)
-/* ns1:rename_object */
-struct ns1__rename_USCOREobject_
-{
-	char *key;	/* optional element of type xsd:string */
-	char *newkey;	/* optional element of type xsd:string */
+#ifndef SOAP_TYPE_ns1__swap_USCOREobjects
+#define SOAP_TYPE_ns1__swap_USCOREobjects (18)
+/* ns1:swap_objects */
+struct ns1__swap_USCOREobjects
+{
+	char *key1;	/* optional element of type xsd:string */
+	char *key2;	/* optional element of type xsd:string */
 };
 #endif
 
 #ifndef SOAP_TYPE_ns1__replicate_USCOREobjectResponse
-#define SOAP_TYPE_ns1__replicate_USCOREobjectResponse (19)
+#define SOAP_TYPE_ns1__replicate_USCOREobjectResponse (20)
 /* ns1:replicate_objectResponse */
 struct ns1__replicate_USCOREobjectResponse
@@ -108,5 +108,5 @@
 
 #ifndef SOAP_TYPE_ns1__replicate_USCOREobject
-#define SOAP_TYPE_ns1__replicate_USCOREobject (20)
+#define SOAP_TYPE_ns1__replicate_USCOREobject (21)
 /* ns1:replicate_object */
 struct ns1__replicate_USCOREobject
@@ -333,7 +333,7 @@
 SOAP_FMAC5 int SOAP_FMAC6 ns1__create_USCOREobject(struct soap*, char *key, char *volume, char **result);
 
-SOAP_FMAC5 int SOAP_FMAC6 ns1__rename_USCOREobject(struct soap*, char *key, char *newkey, char **result);
-
-SOAP_FMAC5 int SOAP_FMAC6 ns1__rename_USCOREobject_(struct soap*, char *key, char *newkey, char **result);
+SOAP_FMAC5 int SOAP_FMAC6 ns1__rename_USCOREobject(struct soap*, char *key1, char *key2, int *result);
+
+SOAP_FMAC5 int SOAP_FMAC6 ns1__swap_USCOREobjects(struct soap*, char *key1, char *key2, char **result);
 
 SOAP_FMAC5 int SOAP_FMAC6 ns1__replicate_USCOREobject(struct soap*, char *key, char *volume, char **result);
@@ -360,7 +360,7 @@
 SOAP_FMAC5 int SOAP_FMAC6 soap_call_ns1__create_USCOREobject(struct soap *soap, const char *soap_endpoint, const char *soap_action, char *key, char *volume, char **result);
 
-SOAP_FMAC5 int SOAP_FMAC6 soap_call_ns1__rename_USCOREobject(struct soap *soap, const char *soap_endpoint, const char *soap_action, char *key, char *newkey, char **result);
-
-SOAP_FMAC5 int SOAP_FMAC6 soap_call_ns1__rename_USCOREobject_(struct soap *soap, const char *soap_endpoint, const char *soap_action, char *key, char *newkey, char **result);
+SOAP_FMAC5 int SOAP_FMAC6 soap_call_ns1__rename_USCOREobject(struct soap *soap, const char *soap_endpoint, const char *soap_action, char *key1, char *key2, int *result);
+
+SOAP_FMAC5 int SOAP_FMAC6 soap_call_ns1__swap_USCOREobjects(struct soap *soap, const char *soap_endpoint, const char *soap_action, char *key1, char *key2, char **result);
 
 SOAP_FMAC5 int SOAP_FMAC6 soap_call_ns1__replicate_USCOREobject(struct soap *soap, const char *soap_endpoint, const char *soap_action, char *key, char *volume, char **result);
@@ -392,5 +392,5 @@
 SOAP_FMAC5 int SOAP_FMAC6 soap_serve_ns1__rename_USCOREobject(struct soap*);
 
-SOAP_FMAC5 int SOAP_FMAC6 soap_serve_ns1__rename_USCOREobject_(struct soap*);
+SOAP_FMAC5 int SOAP_FMAC6 soap_serve_ns1__swap_USCOREobjects(struct soap*);
 
 SOAP_FMAC5 int SOAP_FMAC6 soap_serve_ns1__replicate_USCOREobject(struct soap*);
